@@ -38,40 +38,28 @@ def Main_FCD_pipeline(bids_dir, output_dir, work_dir, analysis_mode, controls, p
     if not os.path.exists(fcdproc_dir):
         os.makedirs(fcdproc_dir)
 
-
-    if fs_reconall == True:
-        print('running reconall')
-
-        fsdir = pe.Node(
-            BIDSFreeSurferDir(
-                derivatives=output_dir,
-                freesurfer_home=os.getenv('FREESURFER_HOME'),
-                spaces= ['fsnative']),
-            name='fsdir', 
-            run_without_submitting=True)        
+    
+    fsdir = pe.Node(
+        BIDSFreeSurferDir(
+            derivatives=output_dir,
+            freesurfer_home=os.getenv('FREESURFER_HOME'),
+            spaces= ['fsnative']),
+        name='fsdir', 
+        run_without_submitting=True)        
         
-        if fs_subjects_dir != "freesurfer":
-            fsdir.inputs.subjects_dir = fs_subjects_dir
-    #else:
-    #    if fs_subjects_dir ==  "freesurfer":
-    #        subjects_dir = os.path.join(output_dir+'/freesurfer/')
-    #    else: 
-    #        subjects_dir = fs_subjects_dir
-    
-    
+    if fs_subjects_dir != "freesurfer":
+        fsdir.inputs.subjects_dir = fs_subjects_dir
+
     subjects = controls + pt_positive + pt_negative
- 
+
     anat_dir = pe.Node(DataFinder(root_paths=fcdproc_dir, max_depth=0),name='anat_dir', run_without_submitting=True)
         
     if analysis_mode == 'preprocess':
         for subject_id in subjects:
             print(f"single procesing subject {subject_id}")
             single_subject_wf = init_single_subject_wf(subject_id, bids_dir, output_dir, work_dir)
-            
-            if fs_reconall:
-                fcdproc_wf.connect(fsdir, 'subjects_dir', single_subject_wf, 'inputnode.subjects_dir')
-            else:
-                fcdproc_wf.add_nodes([single_subject_wf])
+            fcdproc_wf.connect(fsdir, 'subjects_dir', single_subject_wf, 'inputnode.subjects_dir')
+
                 
     if analysis_mode == 'model':
         
@@ -88,11 +76,8 @@ def Main_FCD_pipeline(bids_dir, output_dir, work_dir, analysis_mode, controls, p
         for subject_id in pt_negative:
             
             single_subject_wf = init_single_subject_wf(subject_id, bids_dir, output_dir, work_dir)
-        
-            if fs_reconall:
-                fcdproc_wf.connect(fsdir, 'subjects_dir', single_subject_wf, 'inputnode.subjects_dir')
-            else:
-                fcdproc_wf.add_nodes([single_subject_wf])
+            fcdproc_wf.connect(fsdir, 'subjects_dir', single_subject_wf, 'inputnode.subjects_dir')
+
                             
         #getting ready for fcd detector apply       
         anat_direcotry = anat_dir.clone(name='anatomical_dir')
